==> pgadmin4-9.8-x64.zip: pgAdmin 4.app/Contents/Frameworks/Python.framework/Versions/3.13/Frameworks/Tcl.framework/Versions/8.6/._tclConfig.sh <==
    Mac OS X            	   2  /4     /f                                      ATTR      /f  L  .                 L     com.apple.cs.CodeDirectory       ,  com.apple.cs.CodeEntitlements      
D     com.apple.cs.CodeRequirements      
     com.apple.cs.CodeRequirements-1      #Z  com.apple.cs.CodeSignature                 4        !             Iorg.pgadmin.pgadmin4 TCHGL2R7C5 (NEg;(P.(                                        B,4C}è\_6                    ;Q?:6p£Oqq  ,<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
    <!--
        Disable Sandboxing. This must be enabled for the app store, but it will
        cause Electron to fail to start with an error like:

            [1004/170922.238911:ERROR:directory_reader_posix.cc(42)] opendir /dev/fd: Operation not permitted (1)

        We should figure out why that happens and fix it one day, but for now
        we just don't support the app store.
    -->
    <key>com.apple.security.app-sandbox</key>
    <false/>

    <!--
        Set the app group name for IPC and access to shared containers between
        our processes.
    -->
    <key>com.apple.security.application-groups</key>
    <string>TCHGL2R7C5.org.pgadmin.pgadmin4</string>

    <!--
        We have no need for JIT on x86_64, but Electron won't start without it
        on Apple Silicon.
    -->
    <key>com.apple.security.cs.allow-jit</key>
    <true/>

    <!--
        Explicitly disallow executable code overwriting/patching.
    -->
    <key>com.apple.security.cs.allow-unsigned-executable-memory</key>
    <false/>

    <!--
        Explicitly disallow use of dynamic loader environment variables that
        could be used for code injection.
    -->
    <key>com.apple.security.cs.allow-dyld-environment-variables</key>
    <false/>

    <!--
        Explicitly ensure that library validation is enabled so we only load
        libraries and frameworks signed by us or Apple.
    -->
    <key>com.apple.security.cs.disable-library-validation</key>
    <false/>

    <!--
        We need to enable this, even though we don't modify our own executables.
        Otherwise, Electron just bombs out.
    -->
    <key>com.apple.security.cs.disable-executable-page-protection</key>
    <true/>

    <!--
        We're not a debugger (well, except for procedural languages in Postgres,
        but that doesn't count).
    -->
    <key>com.apple.security.cs.debugger</key>
    <false/>
</dict>
</plist>
                            org.pgadmin.pgadmin4                  
*Hcd                   
*Hcd
                
subject.OU        
TCHGL2R7C5               4        !              Iorg.pgadmin.pgadmin4 TCHGL2R7C5 :F'./Na6洁8                                                                 Zh<W5|mhԭU'A}                                0h'G_ѻuڃYҋ[(0	*H
010
	`He 0	*H
  k00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00$]F0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
231127141403Z
270201221215Z010
	&,d
TCHGL2R7C51:08U1Developer ID Application: David Page (TCHGL2R7C5)10U
TCHGL2R7C510U

David Page10	UGB0"0
	*H
  0
 b5BvE}ɮKz:Pfxݛ:@%Ƀ$PnUc?KVZAC˔`qRI/"<9?DqlySV gg_?`[ǫ2af2
Ja1)o;mp{Rf'9$t7`1 r-KbkQS.̖xT#MG噢4A>A$SZuYTk󖢭o(APܖ	 00U0 0U#0W|-,T0@+40200+0$http://ocsp.apple.com/ocsp03-devid060U 00	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.06+*http://www.apple.com/certificateauthority/0U%0
+0UTaTd0D}eE0U0
*Hcd!20231127000000Z0
*Hcd
 0
	*H
  rnaXKyI7 :va=a1L2L-ZZL2eKh{I ʻ`HpUtƺݵMf
;i)wt6&tT!20$iD]8:ME<dj8eRr*Wo)~'
	'[B즚nC;$!10?AvfD?-oR`"}Z$6ui(5eRJ!1000y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS$]F0
	`He %0	*H
	1	*H
0	*H
	1
250902140634Z0/	*H
	1" iA=8V3Cn|@8ųeb7zo0[	*Hcd	1N0+հ:"왦Z0-	`He JzsoôFkAeBz0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		zNWwyDof1v2Vupe1rMQi7JmmWn8=
		</data>
		<data>
		j58d80rn7Xpzb8O0AUaT8GsbQWU=
		</data>
	</array>
</dict>
</plist>
0
	*H
  ۰2'^Y?7
RW&s峍:DܹjIrϊEyӭm&l=pVvk5a
1ꄘ:D z\BJIhYG^dk
QsbݍD&?~rhӳZ#o>עMh&ߛOLZO BYVMRz
[1+	1[_r煶Ъ5
%Z"W#q;RÇ|"S
İb۳0*H
	10	*H
010	+ 0z*H
	ki0g*010
	`He  -ܳ,bqd^3涯V4hWл?)Bs20250902140634Z0%:&X_
00;/{0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
250818174519Z
250929174518Z0A10UTimestamp Signer MA110U

Apple Inc.10	UUS0"0
	*H
  0
 1+9O3Pd"\3GA|$1du9b\D
hQg8CA4<bjMc|9L+(=\Ȅ`dK'*XeoJ?VY0fX?W:1UNW4T&T6SOܰu_,ʖFهΡD}%,)Պ~C7RGޮtSUyFfq#O
JcK})s 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U!?P
43nlo0U0
	*H
  ˖Sa	KaCq"bҚ&ߦpsi<hbTWn/  ?Ud={D<&XAY'8`I~L+ܴ޺/
!e;IKn;
XMajæuM;\))1q7TNΣ-A[7\--SQ}|л*'Kn@xZ/4*ؿHD,[00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS;/{0	+ 0	*H
	1
*H
	0	*H
	1
250902140634Z0#	*H
	1Kl&-A+&-0+*H
	1000{?e9N ɵ-0
	*H
  Sopٮ0Sys, <.Ns걒uEfRiF)#b34M#\Ͼ@1h(NUFէ]j
L/&ҁ2I, #Aȟ4}9n{zqG!e
%K\+),hF5~*Ym>JW}yi"svBM% #ʈpN񎪲6в	aG!]a	hk      

==> pgadmin4-9.10-x64.zip: pgAdmin 4.app/Contents/Frameworks/Python.framework/Versions/3.13/Frameworks/Tcl.framework/Versions/8.6/._tclConfig.sh <==
    Mac OS X            	   2  /5     /g                                      ATTR      /g  L  .                 L     com.apple.cs.CodeDirectory       ,  com.apple.cs.CodeEntitlements      
D     com.apple.cs.CodeRequirements      
     com.apple.cs.CodeRequirements-1      #[  com.apple.cs.CodeSignature                 4        !r             Iorg.pgadmin.pgadmin4 TCHGL2R7C5 (NEg;(P.(                                        B,4C}è\_6                    Zb;5*Nyqq  ,<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
    <!--
        Disable Sandboxing. This must be enabled for the app store, but it will
        cause Electron to fail to start with an error like:

            [1004/170922.238911:ERROR:directory_reader_posix.cc(42)] opendir /dev/fd: Operation not permitted (1)

        We should figure out why that happens and fix it one day, but for now
        we just don't support the app store.
    -->
    <key>com.apple.security.app-sandbox</key>
    <false/>

    <!--
        Set the app group name for IPC and access to shared containers between
        our processes.
    -->
    <key>com.apple.security.application-groups</key>
    <string>TCHGL2R7C5.org.pgadmin.pgadmin4</string>

    <!--
        We have no need for JIT on x86_64, but Electron won't start without it
        on Apple Silicon.
    -->
    <key>com.apple.security.cs.allow-jit</key>
    <true/>

    <!--
        Explicitly disallow executable code overwriting/patching.
    -->
    <key>com.apple.security.cs.allow-unsigned-executable-memory</key>
    <false/>

    <!--
        Explicitly disallow use of dynamic loader environment variables that
        could be used for code injection.
    -->
    <key>com.apple.security.cs.allow-dyld-environment-variables</key>
    <false/>

    <!--
        Explicitly ensure that library validation is enabled so we only load
        libraries and frameworks signed by us or Apple.
    -->
    <key>com.apple.security.cs.disable-library-validation</key>
    <false/>

    <!--
        We need to enable this, even though we don't modify our own executables.
        Otherwise, Electron just bombs out.
    -->
    <key>com.apple.security.cs.disable-executable-page-protection</key>
    <true/>

    <!--
        We're not a debugger (well, except for procedural languages in Postgres,
        but that doesn't count).
    -->
    <key>com.apple.security.cs.debugger</key>
    <false/>
</dict>
</plist>
                            org.pgadmin.pgadmin4                  
*Hcd                   
*Hcd
                
subject.OU        
TCHGL2R7C5               4        !r              Iorg.pgadmin.pgadmin4 TCHGL2R7C5 :F'./Na6洁8                                                                 Zh<W5|mhԭU'A}                                0>į1AW!Nڳ+90	*H
010
	`He 0	*H
  k00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!00$]F0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
231127141403Z
270201221215Z010
	&,d
TCHGL2R7C51:08U1Developer ID Application: David Page (TCHGL2R7C5)10U
TCHGL2R7C510U

David Page10	UGB0"0
	*H
  0
 b5BvE}ɮKz:Pfxݛ:@%Ƀ$PnUc?KVZAC˔`qRI/"<9?DqlySV gg_?`[ǫ2af2
Ja1)o;mp{Rf'9$t7`1 r-KbkQS.̖xT#MG噢4A>A$SZuYTk󖢭o(APܖ	 00U0 0U#0W|-,T0@+40200+0$http://ocsp.apple.com/ocsp03-devid060U 00	*Hcd00+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.06+*http://www.apple.com/certificateauthority/0U%0
+0UTaTd0D}eE0U0
*Hcd!20231127000000Z0
*Hcd
 0
	*H
  rnaXKyI7 :va=a1L2L-ZZL2eKh{I ʻ`HpUtƺݵMf
;i)wt6&tT!20$iD]8:ME<dj8eRr*Wo)~'
	'[B즚nC;$!10?AvfD?-oR`"}Z$6ui(5eRJ!1000y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS$]F0
	`He %0	*H
	1	*H
0	*H
	1
251110092625Z0/	*H
	1" Qk^߰ 8$ӾnZSu0[	*Hcd	1N0+Q.bv
~0-	`He }鳜JD  eCR,h%i}!Cj/0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		g6JR0C5iv8IddrIK9a0a/Rt+uL8=
		</data>
		<data>
		femznEpE2CAAZUOcUixonCVpnX0=
		</data>
	</array>
</dict>
</plist>
0
	*H
  Dec2n7h~+)J 8L3@daD[v0VvA!4`xon1.*.,]o-s_0_ͭNC]>PB6FΎG
Ow?j* &LYX(Q XFEj9*?j_0+6ܞOEP+iY8u䶲c90A]r9#d輧 *0*H
	10	*H
010	+ 0{*H
	lj0h*010
	`He  OmmXeEdߚsIJlwj.qNt#Ґ髩20251110092625Z0	 rHU
00oz0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
251013173520Z
251124173519Z0A10UTimestamp Signer MA210U

Apple Inc.10	UUS0"0
	*H
  0
 Alv
]kZF) $
	vy5*CQNsS;!!f5RUB*,7+BﴚdW;
6Ƕڀ7dɉx&q{
aws/(DI-G9@87lgHD"!ͽO#A˳p?U1+.ɶޒM4gm
nr#P(@Lu 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U|"Pߢ_\Vd0U0
	*H
  #h,&[a'E'Rb4"IPrmoW5ROt(Yr?qKkz%cH[E$mQTgM%fi:c*ũ)!@涪
R@[YQu:w߲TL>H愀)WrHX76RV[8lmzDɒwN~~֭2twātӀ&N}VV~D00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSoz0	+ 0	*H
	1
*H
	0	*H
	1
251110092625Z0#	*H
	1<,,2l?q[uA0+*H
	1000-(tWY#ţg	7M0
	*H
  y{EDpVM]_8`aɼYomyg]Kzֽ+DPCy܈_~FHZZ"eZ*ZNm/ `D mBK];šަ?yhEͨjl
)W>9NLxQr:}0@)8
~uLbˀ.%OpH

Լw;+8sDSbez.M6k0BxHdŜ(D>é      
